### Name: featureSignif
### Title: Feature significance for kernel density estimation
### Aliases: featureSignif
### Keywords: smooth

### ** Examples

## Non-interactive examples

## Univariate example
data(earthquake)
eq3 <- -log10(-earthquake[,3])

featureSignif(eq3, addSignifGradRegion=TRUE,xlab="-log(-depth)", bw=0.1)

## combined signif. gradient plot and gradient SiZer plot
layout(matrix(1:2, nrow=2))
featureSignif(eq3, addSignifGradRegion=TRUE,xlab="-log(-depth)", bw=0.1)
xlim <- par()$usr[1:2]
featureSignif(eq3, plotSiZer=TRUE, xlab="-log(-depth)", xlim=xlim)
lines(c(-2, 2), c(0.1, 0.1))
layout(1)

## Bivariate example

library(MASS)
data(geyser)

fs <- featureSignif(geyser, addSignifGradRegion=TRUE,
     addSignifCurvRegion=TRUE, bw=c(4.5, 0.37))
names(fs)

## Trivariate example

data(earthquake)
earthquake[,3] <- -log10(-earthquake[,3])

featureSignif(earthquake, scaleData=TRUE, addData=TRUE,
    bw=c(0.0381, 0.0381, 0.0442))

featureSignif(earthquake, addKDE=FALSE, scaleData=TRUE,
   addSignifGradRegion=TRUE, addSignifCurvRegion=TRUE,
   bw=c(0.0381, 0.0381, 0.0442),
   xlim=c(0.4,0.5), ylim=c(0.4,0.5), zlim=c(0.8,0.9))

## Quadrivariate example

library(MASS)
data(iris) 
featureSignif(iris[,1:4], addSignifGradData=TRUE,
   addSignifCurvRegion=TRUE, bw=c(0.457, 0.210, 0.960, 0.413))

## Not run: 
##D ## Interactive examples
##D 
##D library(MASS)
##D data(geyser)
##D duration <- geyser$duration 
##D 
##D ## Univariate example
##D 
##D featureSignif(duration)
##D featureSignif(duration, addData=TRUE)
##D featureSignif(duration, addSignifGradRegion=TRUE,
##D    addSignifGradData=TRUE)
##D featureSignif(duration, addSignifCurvRegion=TRUE,
##D    addSignifCurvData=TRUE)
##D 
##D ## Bivariate example
##D 
##D featureSignif(geyser, addData=TRUE, addSignifGradRegion=TRUE,
##D    addSignifGradData=TRUE, bw=rbind(c(1, 0.1), c(5, 0.9)))
##D    ## bandwidths ranges: h1 in c(1, 5), h2 in c(0.1, 0.9)
##D 
##D ## Trivariate example
##D 
##D data(earthquake)
##D earthquake$depth <- -log10(-earthquake$depth)
##D featureSignif(earthquake, addSignifGradRegion=TRUE, scaleData=TRUE)
##D 
##D ## Quadrivariate example
##D 
##D library(MASS)
##D data(iris)
##D featureSignif(iris[,1:4], addSignifGradData=TRUE, addSignifCurvRegion=TRUE)
## End(Not run)



